Module process_group

Module process_group 

ProcessGroup - Process Group Abstraction

File

crates/axonml-distributed/src/process_group.rs

Author

Andrew Jewell Sr - AutomataNexus

Updated

March 8, 2026

Disclaimer

Use at own risk. This software is provided “as is”, without warranty of any kind, express or implied. The author and AutomataNexus shall not be held liable for any damages arising from the use of this software.

Structs

ProcessGroup
A group of processes that can communicate with each other.
World
Global distributed world.